samsara_bus_dart library
A multi-topic RxDart-based message/event bus for Dart.
This library provides a message bus implementation with support for:
- Registering topics with specific message types and stream behaviors
- Type-safe message emission and consumption
- Connecting topics with mapping functions
- Injecting external streams into topics
- Message correlation across topics
Classes
- DefaultSamsaraBus
- Default implementation of the SamsaraBus interface.
- GlobalSamsaraBus
- A global singleton implementation of SamsaraBus that delegates all calls to an internal DefaultSamsaraBus instance.
-
MessageEnvelope<
T> - A wrapper class for messages/events emitted through the bus.
- SamsaraBus
- The main message bus interface that manages multiple topics.
-
Topic<
T> - A topic in the message bus.
Enums
- TopicType
- Types of subjects that can be used for topics